@@ -1,11 +1,11 @@
-import importlib
+import importlib.metadata
 
-import werkzeug
 from werkzeug.exceptions import HTTPException
 
-_version = importlib.metadata.version('werkzeug').split('.')[0]
+_version = importlib.metadata.version("werkzeug").split(".")[0]
+
+if _version in ("0", "1"):
 
-if _version in ('0', '1'):
     class _HTTPException(HTTPException):
         def __init__(self, code, body, headers, response=None):
             super().__init__(None, response)
@@ -20,6 +20,7 @@ if _version in ('0', '1'):
         def get_headers(self, environ=None):
             return self.headers
 else:
+
     class _HTTPException(HTTPException):
         def __init__(self, code, body, headers, response=None):
             super().__init__(None, response)
