@@ -31,3 +31,19 @@ def user(db):
     user.save()
     yield user
     user.delete()
+
+
+@pytest.fixture
+def token(user):
+    token = OAuth2Token(
+        user_id=user.pk,
+        client_id="client-id",
+        token_type="bearer",
+        access_token="a1",
+        refresh_token="r1",
+        scope="profile",
+        expires_in=3600,
+    )
+    token.save()
+    yield token
+    token.delete()
